@@ -2,15 +2,12 @@ import os
 import sys
 from argparse import ArgumentParser, Namespace
 
-non_chatgpt_params = [
-    "subcommand",
-    "message",
-    "conf",
-    "show",
-    "hide",
-    "multiline",
-    "no_multiline",
-    "show_cost",
+direct_chatgpt_params = [
+    "key",
+    "model",
+    "max_tokens",
+    "min_max_tokens",
+    "tokens_limit",
 ]
 
 
@@ -40,10 +37,22 @@ def get_arg_parser() -> ArgumentParser:
     )
     arg_parser.add_argument(
         "-t",
-        "--tokens",
+        "--max_tokens",
         help="The maximum number of tokens to generate in the chat completion. Set 0 to use the max values for the model minus prompt tokens.",
         type=int,
     )
+    arg_parser.add_argument(
+        "-T",
+        "--min_max_tokens",
+        help="The minimum of max_tokens for the completion when max_tokens = 0.",
+        type=int,
+    )
+    arg_parser.add_argument(
+        "-l",
+        "--tokens_limit",
+        help="The limit of the total tokens of the prompt and the completion. Set 0 to use the max values for the model.",
+        type=int,
+    )
     arg_parser.add_argument(
         "--show",
         help="Show prompt for ask command.",
@@ -64,6 +73,16 @@ def get_arg_parser() -> ArgumentParser:
         help="Use single line input for chat command.",
         action="store_true",
     )
+    arg_parser.add_argument(
+        "--vi",
+        help="Use vi mode at chat.",
+        action="store_true",
+    )
+    arg_parser.add_argument(
+        "--emacs",
+        help="Use emacs mode at chat.",
+        action="store_true",
+    )
     arg_parser.add_argument(
         "--show_cost",
         help="Show cost used.",
